function contourslices(x1,x2,x3,y3d,fignum)
% ctlh = i3Dcontourslice(x1,x2,x3,y3d,fignum)
% creates an interactive contourslice through 3D data. x1 is the axis along the
% first dimension, x2 the axis along the second dimension, x3 along the third dimension. The first
% and second dimension will be used as x and y axis of the contour. The figure number
% defaults to 1. Sometimes a call to i2Dcut_nox(y2d,fignum) makes live
% easier
% 
% Andrin Doll, 2012-2015
% Stephan Pribitzer, 2015

% parse input

% example call
% peaks3d = repmat(peaks,[1 1 100]);
% for ii = 1:size(peaks3d,3); peaks3d(:,:,ii) = circshift(squeeze(peaks3d(:,:,ii)),ii); end
% i3Dcontourslice(1:size(peaks3d,1),1:size(peaks3d,2),1:size(peaks3d,3),peaks3d,10)

% figure number provided?

if ~exist('y3d','var')
    % move first argument to y2d
    y3d = x1;
    % check for second argument
    if exist('x2','var')
        if length(x2) == 1
            fignum = x2;
        else
            error('For the minimalistic call, the second argument is the figure number')
        end
    end
    x1 = 1:size(y3d,1);
    x2 = 1:size(y3d,2);
    x3 = 1:size(y3d,3);
end

if ~exist('fignum','var')
    figure
else
    figure(fignum)
end

clf

contour(x1,x2,squeeze(y3d(:,:,1)));

for ii=1:length(x3)
    setappdata(gca,['dta' num2str(ii)],(squeeze(y3d(:,:,ii))));
end

maxval = max(max(max((y3d))));
minval = min(min(min((y3d))));
N_contour = 15;
values = linspace(minval,maxval,N_contour);
setappdata(gca,'v',values);
setappdata(gca,'x1',x1);
setappdata(gca,'x2',x2);
setappdata(gca,'x3',x3);
setappdata(gca,'XLim',get(gca,'XLim'))
setappdata(gca,'YLim',get(gca,'YLim'))
setappdata(gca,'view',get(gca,'View'))
% ctlh.linedat = y2d;

% get handles and set figure props
fh = gcf;
ah = gca;

% This avoids flickering when updating the axis
set(fh,'doublebuffer','on');

% Generate constants for use in uicontrol initialization
pos=get(ah,'position');

% y text
ytext.pos = [pos(1)+pos(3)+0.005 pos(2) 0.06 0.05];
ytext.h = uicontrol(fh,'style','text', ...
    'units','normalized','position',ytext.pos,'String',num2str(x3(1)), ...
    'BackgroundColor',get(fh,'color'));
setappdata(gca,'ytext',ytext.h);

% yslide
yslide.pos=[pos(1)+pos(3)+0.02 pos(2)+0.1 0.03 pos(4)-0.2];
yslide.min = 1;
yslide.npts = 1000; % axis window dx by number of points
yslide.max = length(x3); % allows for overscaling
yslide.steps = length(x3)-1;

yslide.h=uicontrol(fh,'style','slider',...
    'units','normalized','position',yslide.pos,...
    'callback',@scroller,'min',yslide.min,'max',yslide.max,'SliderStep',[1 1]./yslide.steps,'value',1);


addlistener(yslide.h,'ContinuousValueChange',@scroller);

zoomer=zoom;
zoomer.ActionPostCallback = @zoomcallback;

roter = rotate3d;
roter.ActionPostCallback = @rotatecallback;

setappdata(gca,'yslide',yslide.h);
setappdata(gca,'zoomer',zoomer.ActionPostCallback);
setappdata(gca,'roter',roter.ActionPostCallback);

set(gcf,'Toolbar','figure')

end

function scroller(obj,evd)
contour(getappdata(gca,'x1'),getappdata(gca,'x2'),getappdata(gca,['dta' num2str(floor(get(getappdata(gca,'yslide'),'value')))]),getappdata(gca,'v'))
zoom reset
set(gca,'YLim',getappdata(gca,'YLim'));
set(gca,'XLim',getappdata(gca,'XLim'));
set(gca,'View',getappdata(gca,'view'));

set(getappdata(gca,'ytext'),'String',num2str(subsref(getappdata(gca,'x2'),struct('type','()','subs',{{(floor(get(getappdata(gca,'yslide'),'value')))}}))));
end


function zoomcallback(obj,evd)
setappdata(gca,'XLim',get(gca,'XLim'))
setappdata(gca,'YLim',get(gca,'YLim'))
end


function rotatecallback(obj,evd)
newView = round(evd.Axes.View);
setappdata(gca,'view',newView);
end