clear system
clear all
clear sequence
clear options

t2_vec=550:3:800; 

% the spectral sampling
c=1.4;      % center frequency of Gaussian distribution of spins, in GHz
g=0.01;     % width of the Gaussian distribution in GHz
nu0_s=1.3;  % starting value for sampling of Gaussian distribution
nu0_e=1.5;  % final value for sampling of Gaussian distribution
st=0.001;   % stepsize for sampling of Gaussian distribution
nu0_vec=nu0_s:st:nu0_e;     % creates vector with resonance frequencies, according to above
p=exp(-((c-nu0_vec)/g).^2); % probabilities for each spin
p=p/trapz(p);

% the system
system.sqn=[0.5 0.5];       % spin quantum number of first spin
system.interactions={1,0, 'z','e',1.4;     % Zeeman term of electron, value is replaced in loop
                     2,0,'z','e',-0.014;   % Zeeman of nucleus
                     1,2, 'z','z',-0.045;  % secular part of hyperfine interaction , A*SzIz
                     1,2, 'z','x',0.008};  % pseudo secular part of hyperfine interaction , B*SzIz
system.init_state='-z'; % only the electron spin is quantizised along z, nucleus is not defined, same statement would be '-ze'
system.eq = 'init';  % equilibrium state is the same as initial state

% the options
options.relaxation=0;       % tells SPIDYAN whether to include relaxation (1) or not (0)
options.down_conversion=0;  % downconversion of signal (1) or not (0)
options.det_op={'pe'};      % detection operator


% the sequence
sequence.tp=[50,300,25,500,10]; % vector with event lengths in ns
sequence.beta(1)=pi/2;        % flip angle for first event, tells SPIDYAN that 1st event is a pulse
sequence.beta(3)=pi;          % flip angle for second event, tells SPIDYAN that 2nd event is a pulse
sequence.frq={[1.3 1.5]};     % initial and final frequency of the chirp
sequence.t_rise=10;           % rise time of chirp pulses
sequence.excite={[1 0]};      % only excite the first spin during the pulses
sequence.detection(5)=1;
sequence.stepwise_evolution=sequence.detection; %stepwise evolution for fourth event

echos=zeros(size(t2_vec));

%Send to 'triple'
[experiment,options] = triple(sequence, options);
%%
tmax=t2_vec+0.5*sequence.tp(1);

n_echo_detection = ceil(300/experiment.dt);    % number of points to detect the echo (=length in time domain)

toplot=zeros(length(t2_vec),3601);       %creates empty matrix for spins at all t2 delays

% 'for loop' to calculate time trace for each frequency 'nu0_vec', running 'k'
for k=1:length(nu0_vec)

     system.interactions{1,end}= nu0_vec(k);              % add loop resonance frequency 
     [systeml, state0, options]=setup(system,options);     % calls 'setup': calculates Hamiltonians, etc.
     po=p(k);
     experimentl=experiment;                                % experimentl: every loop is defined independently
     experimentl.tp(2)=t2_vec(1);
     experimentl.tp(4)=tmax(1)-n_echo_detection/2*experiment.dt;
     experimentl.tp(5)=n_echo_detection*experiment.dt;                   % duration of detection time t5

     op=options.detect{1};

     [state, signal, ~, ~,tables]=homerun(state0,systeml,experimentl,options,[]); % 'homerun' calculates timetrace

     toplot(1,:)=toplot(1,:)+signal.sf*p(k);                %sum up signal of different spin packets

     pk=p(k);

     % 'parfor loop' to calculate varying echo delays 't2_vec', running 'm'
     parfor m=2:length(t2_vec)
         
         experimentl=experiment;
         experimentl.tp(2)=t2_vec(m);
         experimentl.tp(4)=tmax(m)-n_echo_detection/2*experiment.dt;
         experimentl.tp(5)=n_echo_detection*experiment.dt; 

         [state, signall]=homerun(state0,systeml,experimentl,options,tables); % 'homerun' calculates timetrace

         toplot(m,:)=toplot(m,:)+signall.sf*pk;             %sum up signal from different t2 values
     end                 
end

t=linspace(0,experiment.tp(end),length(toplot)); % creates time axis
signaldc=strike(toplot, t, c, options);   % down conversion of merged signals
signaldc=signaldc/max(max(signaldc));

figure(3)
plot(t2_vec(1:end),abs(toplot(1:end,1300)))
xlabel('\tau [ns]')
ylabel('Int.')

figure(4)
plot(t2_vec(1:end),abs(toplot(1:end,1849)))
xlabel('\tau [ns]')
ylabel('Int.')