% clear all
clear system
clear sequence
clear options

% This is the spinsystem
system.interactions={1,0,'z','e',1};      % resonance frequency of the first spin in the LO-frame in GHz
system.sqn=0.5;    % spin quantum number of first spin
system.T1=2000;     % relaxation times in ns
system.T2=1000;      
system.init_state='-z'; % initial state

% Rectangular Pulse
rectangular.tp=10;        % length of the pulse in ns
rectangular.nu1=[80];     % flip angle for pulse
rectangular.frq={[1.0]};   % this creates a rectangular pulse
rectangular.t_rise=[0];     % the rise time of the pulse, should be 0 for a rectangular pulse
rectangular.detection=1;   % detection must be switched on

% This block controls other parameters of the simulation
options.relaxation=0;   % tells SPIDYAN whether to include relaxation (1) or not (0)
options.down_conversion=1;    % downconversion of signal (1) or not (0)
options.det_op={'-z','p'}; % cell-array with strings of detection operators
options.no_dc={};       % can be used to exclude certain signals from downconversion
options.LO=8;           % frequency of the local oscillator
options.labframe=0;     % simulate in labframe on (1) or off (0)

options.awg.s_rate=6;  % sampling rate of AWG in GS/s, corresponds to time resolution

% Creates the rectangular pulse
[rectangular, options] = triple(rectangular, options);

% Creates Hamiltonian and initial state
[system, state0, options]=setup(system,options);

% Propagates the system
[state, detected_signal_rectangular, rectangular, options, ~]=homerun(state0, system, rectangular, options, []);

% Display the final state
disp(state)

figure(1),clf % plots expectation values in simulation frame (LO or lab frame)
title('Detected signal in the simulation frame')
hold on
box on
plot(detected_signal_rectangular.t,real(detected_signal_rectangular.sf))
xlabel('t [ns]')
ylabel('<S_q>')
legend(options.det_op)


% This is the pulse sequence of the chirp pulse 
sequence.tp=120;        % length of the pulse in ns
sequence.nu1=0;        % pulse strength in MHz, for flipangle use sequence.beta(1)=pi;
sequence.Q=5;           % critical adiabaticity, sequence.nu1 and sequence.beta need to be zero
% sequence.beta=pi;        % flip angle for pulse, pi is the equivalent statement as Q = 5;
sequence.frq={[0.8 1.2]};   % this creates a rectangular pulse, for a chirp pulse write sequence.frq={[0.9 1.1]}
sequence.t_rise=10;         % rise time of the pulse
sequence.detection=1;        % detection must be switched on

% Creates the pulse and other parameters required to run
[experiment, options] = triple(sequence, options);

% Propagates the system
[state, detected_signal_chirp, experiment, options, tables]=homerun(state0, system, experiment, options, []);

% Display the final state
disp(state)

figure(2),clf % plots pi pulse in simulation frame (LO or lab frame)
title('Detected signal in the simulation frame for a pi pulse')
hold on
box on
plot(detected_signal_chirp.t,real(detected_signal_chirp.dc))
xlabel('t [ns]')
ylabel('<S_q>')
legend(options.det_op)
ylim([-1 1])
xlim([0 120])

figure(3),clf
title('3D plot of spin trajectory after downconversion')
plot3(real(detected_signal_chirp.dc(2,:)),imag(detected_signal_chirp.dc(2,:)),detected_signal_chirp.dc(1,:))
xlabel('<S_x>')
ylabel('<S_y>')
zlabel('<S_z>')

sequence.Q=2*log(2)/pi;   % adiabaticity for a 90degree flip
% sequence.beta = pi/2;       %equivalent statement

% Creates the pulse and other parameters required to run
[experiment, options] = triple(sequence, options);

% Propagates the system
[state, detected_signal_chirp, experiment, options, tables]=homerun(state0, system, experiment, options, []);

% plots pi/2 in simulation frame (LO or lab frame)
figure(4),clf 
title('Detected signal in the simulation frame for a pi/2 pulse')
hold on
box on
plot(detected_signal_chirp.t,real(detected_signal_chirp.dc))
xlabel('t [ns]')
ylabel('<S_q>')
legend(options.det_op)
ylim([-1 1])
xlim([0 120])
