function i2Dcut(x1,x2,y2d,fignum)
% ctlh = i2Dcut(~x1,~x2,y2d,~fignum)
% creates an interactive cut through 2D data. x1 is the axis along the
% first dimension, x2 the axis along the second dimension. The first
% dimension will be used as x axis of the 1d cut. The figure number
% defaults to 1. Sometimes a call to i2Dcut_nox(y2d,fignum) makes live
% easier

% parse input

% x1,x2 omitted? (minimalistic useage)
if ~exist('y2d','var')
    % move first argument to y2d
    y2d = x1;
    % check for second argument
    if exist('x2','var')
        if length(x2) == 1
            fignum = x2;
        else
            error('For the minimalistic call, the second argument is the figure number')
        end
    end
    x1 = 1:size(y2d,1);
    x2 = 1:size(y2d,2);
end

if ~exist('fignum','var')
    figure
else
    figure(fignum)
end

clf

lh = plot(x1,y2d(:,1)); % init with first variable

%%
setappdata(gca,'line',lh);
for ii=1:length(x2)
    setappdata(gca,['dta' num2str(ii)],y2d(:,ii));
end
setappdata(gca,'x2',x2);
setappdata(gca,'x1',x1);
ylims = [min(min(y2d)) 1.01*max(max(y2d))];
xlims = [min(x1) max(x1)];
set(gca,'XLim',xlims);
set(gca,'YLim',ylims);
setappdata(gca,'XLim',xlims);
setappdata(gca,'YLim',ylims);
% ctlh.linedat = y2d;

% get handles and set figure props
fh = gcf;
ah = gca;

% This avoids flickering when updating the axis
set(fh,'doublebuffer','on');

% Generate constants for use in uicontrol initialization
pos=get(ah,'position');


% y text
ytext.pos = [pos(1)+pos(3)+0.005 pos(2) 0.06 0.05];
ytext.h = uicontrol(fh,'style','text', ...
    'units','normalized','position',ytext.pos,'String',num2str(x2(1)), ...
    'BackgroundColor',get(fh,'color'));
setappdata(gca,'ytext',ytext.h);

% yslide
yslide.pos=[pos(1)+pos(3)+0.02 pos(2)+0.1 0.03 pos(4)-0.2];
yslide.min = 1;
yslide.npts = 1000; % axis window dx by number of points
yslide.max = length(x2); % allows for overscaling
yslide.steps = length(x2)-1;


% yslide.call=['set(getappdata(gca,''line''),''ydata'',getappdata(gca,[''dta'' num2str(floor(get(getappdata(gca,''yslide''),''value'')))]));'];
% now the x2 index...
% yslide.call2=['set(getappdata(gca,''ytext''),''String'',num2str(subsref(getappdata(gca,''x2''),struct(''type'',''()'',''subs'',{{(floor(get(getappdata(gca,''yslide''),''value'')))}}))));' ];
% The big hack for matlab 2014b and newer: make a callback function out of
% that string (to make use of addlistener, instead of the old
% handle.listener)
% eval(['yslide.call_fun = @(hObject,callbackdata) ' yslide.call ';']);
% eval(['yslide.call_fun2 = @(hObject,callbackdata) ' yslide.call2 ';']);
yslide.h=uicontrol(fh,'style','slider',...
    'units','normalized','position',yslide.pos,...
    'callback',@scroller,'min',yslide.min,'max',yslide.max,'SliderStep',[1 1]./yslide.steps,'value',1);


addlistener(yslide.h,'ContinuousValueChange',@scroller);

zoomer=zoom;
zoomer.ActionPostCallback = @zoomcallback;

setappdata(gca,'yslide',yslide.h);
setappdata(gca,'zoomer',zoomer.ActionPostCallback);

set(gcf,'Toolbar','figure')

end

function zoomcallback(obj,evd)
setappdata(gca,'XLim',get(gca,'XLim'))
setappdata(gca,'YLim',get(gca,'YLim'))
end

function scroller(obj,evd)
plot(getappdata(gca,'x1'),getappdata(gca,['dta' num2str(floor(get(getappdata(gca,'yslide'),'value')))]))
zoom reset
set(gca,'YLim',getappdata(gca,'YLim'));
set(gca,'XLim',getappdata(gca,'XLim'));

set(getappdata(gca,'ytext'),'String',num2str(subsref(getappdata(gca,'x2'),struct('type','()','subs',{{(floor(get(getappdata(gca,'yslide'),'value')))}}))));
end
% keyboard
